/* global Drupal */

// Ensure $ is available: Foundation and select2 need to bind to it
import $ from 'jquery'
import select2 from 'select2'

import { Foundation, SmoothScroll, Toggler } from 'foundation-sites/js/foundation'
import { SelectTwo, AdaptiveSticky, StickyButton } from '@moreonion/foundation-base'

// Add the select2 to jQuery
// Needed for SelectTwo plugin
select2($)

// Add Foundation to jQuery
Foundation.addToJquery($)

// Configure Foundation
Foundation.plugin(SmoothScroll, 'SmoothScroll')
Foundation.plugin(Toggler, 'Toggler')
Foundation.plugin(SelectTwo, 'SelectTwo')
Foundation.plugin(AdaptiveSticky, 'AdaptiveSticky')
Foundation.plugin(StickyButton, 'StickyButton')

// Let foundation initialize the initial markup
// This needs to be done for dynamically loaded markup too (e.g. AJAX markup)
export function initFoundation () {
  if (typeof Drupal !== 'undefined') {
    Drupal.behaviors.foundist_initialize = {}
    Drupal.behaviors.foundist_initialize.attach = (context, settings) => {
      $(context).foundation()
    }
  } else {
    $(window.document).foundation()
  }
}

// Activate AdaptiveSticky on forms in the sidebar.
export function stickyForm () {
  // Add a wrapper around the #sidebar content to make all of it sticky.
  $('#sidebar').children().wrapAll('<div class="sticky" />')
  // Let the actual form inside #form stick to the window top.
  return new Foundation.AdaptiveSticky($('#sidebar > .sticky'), {
    target: '#form form',
    offset: $('#form').css('padding-top'),
    mediaQuery: 'large'
  })
}

// Activate StickyButton on CTA markup snippet.
export function stickyButton () {
  let $cta = $('.sticky-cta')
  if (!$cta.length) {
    return
  }
  // Put button(s) in right position.
  const target = $cta.find('a').attr('href')
  if ($('#sidebar').length) {
    const $clone = $cta.clone().prependTo($('#sidebar')).addClass('top show-for-large')
    $cta.appendTo('body').addClass('bottom hide-for-large')
    $cta = $cta.add($clone)
  } else {
    $cta.appendTo('body').addClass('bottom')
  }
  // Add SmoothScroll
  const scroll = new SmoothScroll($cta.find('a'))
  // Initialize plugin
  return new Foundation.StickyButton($cta, { after: target })
}
